@@ -19,7 +19,7 @@ from typing import Union, Optional
 
 from .i2c import SupMCUMaster
 from .parsing import parse_telemetry
-from .types import SupMCUTelemetryDefinition, SupMCUModuleDefinition
+from .types import SupMCUTelemetryDefinition, SupMCUModuleDefinition, TelemetryType
 from ..i2c import I2CMaster
 
 SIZEOF_HEADER_FOOTER = 13
@@ -110,9 +110,23 @@ def request_telemetry_definition(i2c_master: Union[I2CMaster, SupMCUMaster],
                                      format_response.items[0].value)
 
 
+def get_name_from_version(i2c_master: Union[I2CMaster, SupMCUMaster], address: int) -> str:
+    """
+    Gets the Short Module name from the version string
+
+    :param i2c_master: The I2C master to write/read the requests from.
+    :param address: The address of the module on the I2C bus.
+    """
+    module_def = SupMCUModuleDefinition("", "", address, {0: SupMCUTelemetryDefinition("Firmware Version", 77, 0, "S")}, {})
+    master = SupMCUMaster(i2c_master, (module_def,))
+    version = master.request_telemetry(address, TelemetryType.SupMCU, 0).items[0].value
+    return version.split()[0]
+
+
+
 def request_module_definition(i2c_master: Union[I2CMaster, SupMCUMaster],
                               address: int,
-                              module_cmd_name: str,
+                              module_cmd_name: Optional[str] = None,
                               module_name: Optional[str] = None,
                               response_delay: Optional[float] = None) -> SupMCUModuleDefinition:
     """
@@ -121,7 +135,7 @@ def request_module_definition(i2c_master: Union[I2CMaster, SupMCUMaster],
 
     :param i2c_master: The I2C master to write/read the requests from.
     :param address: The address of the module on the I2C bus.
-    :param module_cmd_name: The short name of the module as used in telemetry requests (e.g. BM for Battery Module).
+    :param module_cmd_name: Optional, short name of the module as used in telemetry requests (e.g. BM for Battery Module).
     :param module_name: Optional name to give module, if None, then is set to `module_cmd_name`
     :param response_delay: The delay in seconds to wait between I2C read and I2C write.
     :return: The module definition for the device at I2C Address `address`
@@ -130,6 +144,8 @@ def request_module_definition(i2c_master: Union[I2CMaster, SupMCUMaster],
         if response_delay is None:
             response_delay = i2c_master.request_delay
         i2c_master = i2c_master.i2c_master
+    if module_cmd_name is None:
+        module_cmd_name = get_name_from_version(i2c_master, address)
     if response_delay is None:
         # None was set by the SupMCU master or the passed in variable.
         response_delay = _DEFAULT_RESPONSE_DELAY
